@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,36 +18,31 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkcloudapi.endpoint import endpoint_data
-
 class DescribeApisBySignatureRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisBySignature','apigateway')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeApisBySignature')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-	def get_SignatureId(self): # String
-		return self.get_query_params().get('SignatureId')
-
-	def set_SignatureId(self, SignatureId):  # String
-		self.add_query_param('SignatureId', SignatureId)
-	def get_PageNumber(self): # Integer
-		return self.get_query_params().get('PageNumber')
-
-	def set_PageNumber(self, PageNumber):  # Integer
-		self.add_query_param('PageNumber', PageNumber)
-	def get_SecurityToken(self): # String
+	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
-	def get_PageSize(self): # Integer
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
+	def get_PageSize(self):
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self, PageSize):  # Integer
-		self.add_query_param('PageSize', PageSize)
+	def set_PageSize(self,PageSize):
+		self.add_query_param('PageSize',PageSize)
+
+	def get_SignatureId(self):
+		return self.get_query_params().get('SignatureId')
+
+	def set_SignatureId(self,SignatureId):
+		self.add_query_param('SignatureId',SignatureId)
+
+	def get_PageNumber(self):
+		return self.get_query_params().get('PageNumber')
+
+	def set_PageNumber(self,PageNumber):
+		self.add_query_param('PageNumber',PageNumber)
\ No newline at end of file
