@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,26 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkcloudapi.endpoint import endpoint_data
-
 class DescribeRegionsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeRegions','apigateway')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeRegions')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-	def get_Language(self): # String
-		return self.get_query_params().get('Language')
-
-	def set_Language(self, Language):  # String
-		self.add_query_param('Language', Language)
-	def get_SecurityToken(self): # String
+	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
+	def get_Language(self):
+		return self.get_query_params().get('Language')
+
+	def set_Language(self,Language):
+		self.add_query_param('Language',Language)
\ No newline at end of file
