@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,41 +18,37 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkcloudapi.endpoint import endpoint_data
-
 class RemoveAppsAuthoritiesRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveAppsAuthorities','apigateway')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'RemoveAppsAuthorities')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-	def get_StageName(self): # String
+	def get_StageName(self):
 		return self.get_query_params().get('StageName')
 
-	def set_StageName(self, StageName):  # String
-		self.add_query_param('StageName', StageName)
-	def get_GroupId(self): # String
-		return self.get_query_params().get('GroupId')
+	def set_StageName(self,StageName):
+		self.add_query_param('StageName',StageName)
 
-	def set_GroupId(self, GroupId):  # String
-		self.add_query_param('GroupId', GroupId)
-	def get_AppIds(self): # String
+	def get_AppIds(self):
 		return self.get_query_params().get('AppIds')
 
-	def set_AppIds(self, AppIds):  # String
-		self.add_query_param('AppIds', AppIds)
-	def get_SecurityToken(self): # String
+	def set_AppIds(self,AppIds):
+		self.add_query_param('AppIds',AppIds)
+
+	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
-	def get_ApiId(self): # String
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
+	def get_GroupId(self):
+		return self.get_query_params().get('GroupId')
+
+	def set_GroupId(self,GroupId):
+		self.add_query_param('GroupId',GroupId)
+
+	def get_ApiId(self):
 		return self.get_query_params().get('ApiId')
 
-	def set_ApiId(self, ApiId):  # String
-		self.add_query_param('ApiId', ApiId)
+	def set_ApiId(self,ApiId):
+		self.add_query_param('ApiId',ApiId)
\ No newline at end of file
