@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,36 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkcloudapi.endpoint import endpoint_data
-
 class ResetAppSecretRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ResetAppSecret','apigateway')
-		self.set_method('POST')
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'ResetAppSecret')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-	def get_NewAppSecret(self): # String
-		return self.get_query_params().get('NewAppSecret')
-
-	def set_NewAppSecret(self, NewAppSecret):  # String
-		self.add_query_param('NewAppSecret', NewAppSecret)
-	def get_SecurityToken(self): # String
+	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
-	def get_NewAppKey(self): # String
-		return self.get_query_params().get('NewAppKey')
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
 
-	def set_NewAppKey(self, NewAppKey):  # String
-		self.add_query_param('NewAppKey', NewAppKey)
-	def get_AppKey(self): # String
+	def get_AppKey(self):
 		return self.get_query_params().get('AppKey')
 
-	def set_AppKey(self, AppKey):  # String
-		self.add_query_param('AppKey', AppKey)
+	def set_AppKey(self,AppKey):
+		self.add_query_param('AppKey',AppKey)
\ No newline at end of file
